==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/deviceupdate/kotlin/InstanceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.deviceupdate.kotlin

import com.pulumi.azurenative.deviceupdate.InstanceArgs.builder
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.DiagnosticStoragePropertiesArgs
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.DiagnosticStoragePropertiesArgsBuilder
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.IotHubSettingsArgs
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.IotHubSettingsArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Device Update instance details.
 * Azure REST API version: 2023-07-01. Prior API version in Azure Native 1.x: 2020-03-01-preview.
 * ## Example Usage
 * ### Creates or updates Instance
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var instance = new AzureNative.DeviceUpdate.Instance("instance", new()
 *     {
 *         AccountName = "contoso",
 *         DiagnosticStorageProperties = new AzureNative.DeviceUpdate.Inputs.DiagnosticStoragePropertiesArgs
 *         {
 *             AuthenticationType = "KeyBased",
 *             ConnectionString = "string",
 *             ResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/adu-resource-group/providers/Microsoft.Storage/storageAccounts/testAccount",
 *         },
 *         EnableDiagnostics = false,
 *         InstanceName = "blue",
 *         IotHubs = new[]
 *         {
 *             new AzureNative.DeviceUpdate.Inputs.IotHubSettingsArgs
 *             {
 *                 ResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.Devices/IotHubs/blue-contoso-hub",
 *             },
 *         },
 *         Location = "westus2",
 *         ResourceGroupName = "test-rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/deviceupdate/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := deviceupdate.NewInstance(ctx, "instance", &deviceupdate.InstanceArgs{
 * 			AccountName: pulumi.String("contoso"),
 * 			DiagnosticStorageProperties: &deviceupdate.DiagnosticStoragePropertiesArgs{
 * 				AuthenticationType: pulumi.String("KeyBased"),
 * 				ConnectionString:   pulumi.String("string"),
 * 				ResourceId:         pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/adu-resource-group/providers/Microsoft.Storage/storageAccounts/testAccount"),
 * 			},
 * 			EnableDiagnostics: pulumi.Bool(false),
 * 			InstanceName:      pulumi.String("blue"),
 * 			IotHubs: []deviceupdate.IotHubSettingsArgs{
 * 				{
 * 					ResourceId: pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.Devices/IotHubs/blue-contoso-hub"),
 * 				},
 * 			},
 * 			Location:          pulumi.String("westus2"),
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.deviceupdate.Instance;
 * import com.pulumi.azurenative.deviceupdate.InstanceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var instance = new Instance("instance", InstanceArgs.builder()
 *             .accountName("contoso")
 *             .diagnosticStorageProperties(Map.ofEntries(
 *                 Map.entry("authenticationType", "KeyBased"),
 *                 Map.entry("connectionString", "string"),
 *                 Map.entry("resourceId", "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/adu-resource-group/providers/Microsoft.Storage/storageAccounts/testAccount")
 *             ))
 *             .enableDiagnostics(false)
 *             .instanceName("blue")
 *             .iotHubs(Map.of("resourceId", "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.Devices/IotHubs/blue-contoso-hub"))
 *             .location("westus2")
 *             .resourceGroupName("test-rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:deviceupdate:Instance blue /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeviceUpdate/accounts/{accountName}/instances/{instanceName}
 * ```
 * @property accountName Account name.
 * @property diagnosticStorageProperties Customer-initiated diagnostic log collection storage properties
 * @property enableDiagnostics Enables or Disables the diagnostic logs collection
 * @property instanceName Instance name.
 * @property iotHubs List of IoT Hubs associated with the account.
 * @property location The geo-location where the resource lives
 * @property resourceGroupName The resource group name.
 * @property tags Resource tags.
 */
public data class InstanceArgs(
    public val accountName: Output<String>? = null,
    public val diagnosticStorageProperties: Output<DiagnosticStoragePropertiesArgs>? = null,
    public val enableDiagnostics: Output<Boolean>? = null,
    public val instanceName: Output<String>? = null,
    public val iotHubs: Output<List<IotHubSettingsArgs>>? = null,
    public val location: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.deviceupdate.InstanceArgs> {
    override fun toJava(): com.pulumi.azurenative.deviceupdate.InstanceArgs =
        com.pulumi.azurenative.deviceupdate.InstanceArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .diagnosticStorageProperties(
                diagnosticStorageProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .enableDiagnostics(enableDiagnostics?.applyValue({ args0 -> args0 }))
            .instanceName(instanceName?.applyValue({ args0 -> args0 }))
            .iotHubs(
                iotHubs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [InstanceArgs].
 */
@PulumiTagMarker
public class InstanceArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var diagnosticStorageProperties: Output<DiagnosticStoragePropertiesArgs>? = null

    private var enableDiagnostics: Output<Boolean>? = null

    private var instanceName: Output<String>? = null

    private var iotHubs: Output<List<IotHubSettingsArgs>>? = null

    private var location: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Account name.
     */
    @JvmName("fbqrrrqtbpdowsnq")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value Customer-initiated diagnostic log collection storage properties
     */
    @JvmName("yegmobyvkjsrgdmp")
    public suspend fun diagnosticStorageProperties(`value`: Output<DiagnosticStoragePropertiesArgs>) {
        this.diagnosticStorageProperties = value
    }

    /**
     * @param value Enables or Disables the diagnostic logs collection
     */
    @JvmName("hlyfddqvmaochvod")
    public suspend fun enableDiagnostics(`value`: Output<Boolean>) {
        this.enableDiagnostics = value
    }

    /**
     * @param value Instance name.
     */
    @JvmName("mmbtsvfpoupuuasx")
    public suspend fun instanceName(`value`: Output<String>) {
        this.instanceName = value
    }

    /**
     * @param value List of IoT Hubs associated with the account.
     */
    @JvmName("xolcbmxfhpqmdinp")
    public suspend fun iotHubs(`value`: Output<List<IotHubSettingsArgs>>) {
        this.iotHubs = value
    }

    @JvmName("lyhiokbpjhqfxxco")
    public suspend fun iotHubs(vararg values: Output<IotHubSettingsArgs>) {
        this.iotHubs = Output.all(values.asList())
    }

    /**
     * @param values List of IoT Hubs associated with the account.
     */
    @JvmName("advmlxelfvbrpkrk")
    public suspend fun iotHubs(values: List<Output<IotHubSettingsArgs>>) {
        this.iotHubs = Output.all(values)
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("iukxtkbqjhcrsbci")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("lrjkmfigseatfgcb")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("pianeawvfrpashjs")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Account name.
     */
    @JvmName("nipmlpfpmvcbajmw")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value Customer-initiated diagnostic log collection storage properties
     */
    @JvmName("npjqkdxabxdrgqfo")
    public suspend fun diagnosticStorageProperties(`value`: DiagnosticStoragePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diagnosticStorageProperties = mapped
    }

    /**
     * @param argument Customer-initiated diagnostic log collection storage properties
     */
    @JvmName("ebgcpwboikmflarg")
    public suspend
    fun diagnosticStorageProperties(argument: suspend DiagnosticStoragePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = DiagnosticStoragePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.diagnosticStorageProperties = mapped
    }

    /**
     * @param value Enables or Disables the diagnostic logs collection
     */
    @JvmName("eejdftrasomttwmp")
    public suspend fun enableDiagnostics(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableDiagnostics = mapped
    }

    /**
     * @param value Instance name.
     */
    @JvmName("xedrljkbemfogtbf")
    public suspend fun instanceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceName = mapped
    }

    /**
     * @param value List of IoT Hubs associated with the account.
     */
    @JvmName("ovuqimryrcbwohfq")
    public suspend fun iotHubs(`value`: List<IotHubSettingsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iotHubs = mapped
    }

    /**
     * @param argument List of IoT Hubs associated with the account.
     */
    @JvmName("agrqoaeyyhklycyd")
    public suspend fun iotHubs(argument: List<suspend IotHubSettingsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            IotHubSettingsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.iotHubs = mapped
    }

    /**
     * @param argument List of IoT Hubs associated with the account.
     */
    @JvmName("xoqwaqnslkibcobj")
    public suspend fun iotHubs(vararg argument: suspend IotHubSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            IotHubSettingsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.iotHubs = mapped
    }

    /**
     * @param argument List of IoT Hubs associated with the account.
     */
    @JvmName("uyhdjpigicujmxuu")
    public suspend fun iotHubs(argument: suspend IotHubSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IotHubSettingsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.iotHubs = mapped
    }

    /**
     * @param values List of IoT Hubs associated with the account.
     */
    @JvmName("foxhufhirksuctyu")
    public suspend fun iotHubs(vararg values: IotHubSettingsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.iotHubs = mapped
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("opbofgpgncjjbvvk")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("wkfytfjxrqafpmay")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("dowikecivwqoptgi")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("ewtisdiniihofxdg")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): InstanceArgs = InstanceArgs(
        accountName = accountName,
        diagnosticStorageProperties = diagnosticStorageProperties,
        enableDiagnostics = enableDiagnostics,
        instanceName = instanceName,
        iotHubs = iotHubs,
        location = location,
        resourceGroupName = resourceGroupName,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/deviceupdate/kotlin/InstanceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.deviceupdate.kotlin

import com.pulumi.azurenative.deviceupdate.InstanceArgs.builder
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.DiagnosticStoragePropertiesArgs
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.DiagnosticStoragePropertiesArgsBuilder
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.IotHubSettingsArgs
import com.pulumi.azurenative.deviceupdate.kotlin.inputs.IotHubSettingsArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Device Update instance details.
 * Azure REST API version: 2023-07-01. Prior API version in Azure Native 1.x: 2020-03-01-preview.
 * ## Example Usage
 * ### Creates or updates Instance
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var instance = new AzureNative.DeviceUpdate.Instance("instance", new()
 *     {
 *         AccountName = "contoso",
 *         DiagnosticStorageProperties = new AzureNative.DeviceUpdate.Inputs.DiagnosticStoragePropertiesArgs
 *         {
 *             AuthenticationType = "KeyBased",
 *             ConnectionString = "string",
 *             ResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/adu-resource-group/providers/Microsoft.Storage/storageAccounts/testAccount",
 *         },
 *         EnableDiagnostics = false,
 *         InstanceName = "blue",
 *         IotHubs = new[]
 *         {
 *             new AzureNative.DeviceUpdate.Inputs.IotHubSettingsArgs
 *             {
 *                 ResourceId = "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.Devices/IotHubs/blue-contoso-hub",
 *             },
 *         },
 *         Location = "westus2",
 *         ResourceGroupName = "test-rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/deviceupdate/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := deviceupdate.NewInstance(ctx, "instance", &deviceupdate.InstanceArgs{
 * 			AccountName: pulumi.String("contoso"),
 * 			DiagnosticStorageProperties: &deviceupdate.DiagnosticStoragePropertiesArgs{
 * 				AuthenticationType: pulumi.String("KeyBased"),
 * 				ConnectionString:   pulumi.String("string"),
 * 				ResourceId:         pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/adu-resource-group/providers/Microsoft.Storage/storageAccounts/testAccount"),
 * 			},
 * 			EnableDiagnostics: pulumi.Bool(false),
 * 			InstanceName:      pulumi.String("blue"),
 * 			IotHubs: []deviceupdate.IotHubSettingsArgs{
 * 				{
 * 					ResourceId: pulumi.String("/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.Devices/IotHubs/blue-contoso-hub"),
 * 				},
 * 			},
 * 			Location:          pulumi.String("westus2"),
 * 			ResourceGroupName: pulumi.String("test-rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.deviceupdate.Instance;
 * import com.pulumi.azurenative.deviceupdate.InstanceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var instance = new Instance("instance", InstanceArgs.builder()
 *             .accountName("contoso")
 *             .diagnosticStorageProperties(Map.ofEntries(
 *                 Map.entry("authenticationType", "KeyBased"),
 *                 Map.entry("connectionString", "string"),
 *                 Map.entry("resourceId", "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/adu-resource-group/providers/Microsoft.Storage/storageAccounts/testAccount")
 *             ))
 *             .enableDiagnostics(false)
 *             .instanceName("blue")
 *             .iotHubs(Map.of("resourceId", "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/test-rg/providers/Microsoft.Devices/IotHubs/blue-contoso-hub"))
 *             .location("westus2")
 *             .resourceGroupName("test-rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:deviceupdate:Instance blue /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeviceUpdate/accounts/{accountName}/instances/{instanceName}
 * ```
 * @property accountName Account name.
 * @property diagnosticStorageProperties Customer-initiated diagnostic log collection storage properties
 * @property enableDiagnostics Enables or Disables the diagnostic logs collection
 * @property instanceName Instance name.
 * @property iotHubs List of IoT Hubs associated with the account.
 * @property location The geo-location where the resource lives
 * @property resourceGroupName The resource group name.
 * @property tags Resource tags.
 */
public data class InstanceArgs(
    public val accountName: Output<String>? = null,
    public val diagnosticStorageProperties: Output<DiagnosticStoragePropertiesArgs>? = null,
    public val enableDiagnostics: Output<Boolean>? = null,
    public val instanceName: Output<String>? = null,
    public val iotHubs: Output<List<IotHubSettingsArgs>>? = null,
    public val location: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.deviceupdate.InstanceArgs> {
    override fun toJava(): com.pulumi.azurenative.deviceupdate.InstanceArgs =
        com.pulumi.azurenative.deviceupdate.InstanceArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .diagnosticStorageProperties(
                diagnosticStorageProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .enableDiagnostics(enableDiagnostics?.applyValue({ args0 -> args0 }))
            .instanceName(instanceName?.applyValue({ args0 -> args0 }))
            .iotHubs(
                iotHubs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .location(location?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [InstanceArgs].
 */
@PulumiTagMarker
public class InstanceArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var diagnosticStorageProperties: Output<DiagnosticStoragePropertiesArgs>? = null

    private var enableDiagnostics: Output<Boolean>? = null

    private var instanceName: Output<String>? = null

    private var iotHubs: Output<List<IotHubSettingsArgs>>? = null

    private var location: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Account name.
     */
    @JvmName("cgrrmhdkupwywyrc")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value Customer-initiated diagnostic log collection storage properties
     */
    @JvmName("gmtsxmscwcvwueho")
    public suspend fun diagnosticStorageProperties(`value`: Output<DiagnosticStoragePropertiesArgs>) {
        this.diagnosticStorageProperties = value
    }

    /**
     * @param value Enables or Disables the diagnostic logs collection
     */
    @JvmName("ffugpgojehqebmow")
    public suspend fun enableDiagnostics(`value`: Output<Boolean>) {
        this.enableDiagnostics = value
    }

    /**
     * @param value Instance name.
     */
    @JvmName("haperuanuadwchui")
    public suspend fun instanceName(`value`: Output<String>) {
        this.instanceName = value
    }

    /**
     * @param value List of IoT Hubs associated with the account.
     */
    @JvmName("jxjiqfhqxqwtsimh")
    public suspend fun iotHubs(`value`: Output<List<IotHubSettingsArgs>>) {
        this.iotHubs = value
    }

    @JvmName("riefumiejuhuymxk")
    public suspend fun iotHubs(vararg values: Output<IotHubSettingsArgs>) {
        this.iotHubs = Output.all(values.asList())
    }

    /**
     * @param values List of IoT Hubs associated with the account.
     */
    @JvmName("kledsxvacxtndevv")
    public suspend fun iotHubs(values: List<Output<IotHubSettingsArgs>>) {
        this.iotHubs = Output.all(values)
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("tfuvycsjncaedxlo")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("pansobbktbxiuryo")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("fhsmnwbvqllwwifr")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Account name.
     */
    @JvmName("ieciigwqgahrcccq")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value Customer-initiated diagnostic log collection storage properties
     */
    @JvmName("eouheyxjctsrwfcb")
    public suspend fun diagnosticStorageProperties(`value`: DiagnosticStoragePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diagnosticStorageProperties = mapped
    }

    /**
     * @param argument Customer-initiated diagnostic log collection storage properties
     */
    @JvmName("kvauovocdvwislbg")
    public suspend
    fun diagnosticStorageProperties(argument: suspend DiagnosticStoragePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = DiagnosticStoragePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.diagnosticStorageProperties = mapped
    }

    /**
     * @param value Enables or Disables the diagnostic logs collection
     */
    @JvmName("rllfiulffkhxwogu")
    public suspend fun enableDiagnostics(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableDiagnostics = mapped
    }

    /**
     * @param value Instance name.
     */
    @JvmName("svoumsgvrmwmrbhk")
    public suspend fun instanceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.instanceName = mapped
    }

    /**
     * @param value List of IoT Hubs associated with the account.
     */
    @JvmName("ffsjbogpwvuwobfk")
    public suspend fun iotHubs(`value`: List<IotHubSettingsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.iotHubs = mapped
    }

    /**
     * @param argument List of IoT Hubs associated with the account.
     */
    @JvmName("qbmvhgbqjgwiahvg")
    public suspend fun iotHubs(argument: List<suspend IotHubSettingsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            IotHubSettingsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.iotHubs = mapped
    }

    /**
     * @param argument List of IoT Hubs associated with the account.
     */
    @JvmName("vkfppqrfhyrvlyrc")
    public suspend fun iotHubs(vararg argument: suspend IotHubSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            IotHubSettingsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.iotHubs = mapped
    }

    /**
     * @param argument List of IoT Hubs associated with the account.
     */
    @JvmName("nqucftwfwmofplsw")
    public suspend fun iotHubs(argument: suspend IotHubSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IotHubSettingsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.iotHubs = mapped
    }

    /**
     * @param values List of IoT Hubs associated with the account.
     */
    @JvmName("sbkcfkgvvmxhlyvf")
    public suspend fun iotHubs(vararg values: IotHubSettingsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.iotHubs = mapped
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("ncbedbrbalslovfe")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("ssqbykrlwrpswxvi")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("sajdcnaqahxsqkxy")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("nkjtmvjkviwlqumd")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): InstanceArgs = InstanceArgs(
        accountName = accountName,
        diagnosticStorageProperties = diagnosticStorageProperties,
        enableDiagnostics = enableDiagnostics,
        instanceName = instanceName,
        iotHubs = iotHubs,
        location = location,
        resourceGroupName = resourceGroupName,
        tags = tags,
    )
}
